import React from "react";
import PropTypes from "prop-types";
import ForwardComponent from "./ForwardComponent";
import { useParams } from "react-router";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import { loadSessionForwards } from "../../../session/actionCreators";
import Spinner from "../../../../components/common/Spinner";

const ForwardContainer = ({ actions, forward }) => {
  const params = useParams();
  const { sessionId } = params;

  if (!forward) {
    actions.loadSessionForwards(sessionId);
    return <Spinner />;
  }

  return <ForwardComponent forward={forward} />;
};

ForwardContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  forward: PropTypes.object
};

function mapStateToProps(state, route) {
  const { sessionId, forwardId } = route.match.params;
  const session = state.forwards[sessionId];
  const forward = session?.find(z => (z.forwardId = forwardId));

  return {
    forward
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadSessionForwards }, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ForwardContainer);
