import React, { useMemo } from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import {
  Table,
  TableBody,
  TableContainer,
  TableHead,
  TableRow,
  Paper,
  Tooltip
} from "@material-ui/core";
import { useTranslation } from "react-i18next";
import styles from "../../../../../components/common/styles/tableStyles";
import {
  StyledTableCell,
  StyledTableRow
} from "../../../../../components/common/MaterialTable";
import ActiveIcon from "../../../../../components/common/ActiveIcon";
import Typography from "@material-ui/core/Typography";

const useStyles = makeStyles(styles);

const ForwardOptionsComponent = ({ title, options }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  const loading = !options || options.loading;

  const elements = useMemo(
    () => [
      {
        label: "Session.Forwards.Options.TrailingSlash",
        tooltip: "Session.Forwards.Options.TrailingSlashTooltip",
        active: options.trailingSlash
      },
      {
        label: "Session.Forwards.Options.PathOverwrite",
        tooltip: "Session.Forwards.Options.PathOverwriteTooltip",
        active: options.pathOverwrite?.on
      },
      {
        label: "Session.Forwards.Options.PathInjection",
        tooltip: "Session.Forwards.Options.PathInjectionTooltip",
        active: options.pathInjection?.on
      },
      {
        label: "Session.Forwards.Options.KeyOverwrite",
        tooltip: "Session.Forwards.Options.KeyOverwriteTooltip",
        active: options.keyOverwrite?.on
      }
    ],
    [options]
  );

  return (
    <>
      <TableContainer component={Paper}>
        <Table
          className={classes.narrowTable}
          size="small"
          aria-label="customized table"
        >
          <TableHead>
            <TableRow>
              <StyledTableCell>
                {t("Session.Forwards.Options.Name")}
              </StyledTableCell>
              <StyledTableCell align="center">
                {t("Session.Forwards.Options.Active")}
              </StyledTableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            <>
              {elements.map(element => {
                return (
                  <StyledTableRow key={element.label}>
                    <Tooltip title={t(element.tooltip)}>
                      <StyledTableCell>{t(element.label)}</StyledTableCell>
                    </Tooltip>
                    <StyledTableCell align="center">
                      <ActiveIcon active={element.active} loading={loading} />
                    </StyledTableCell>
                  </StyledTableRow>
                );
              })}
            </>
          </TableBody>
        </Table>
      </TableContainer>
      <Typography variant="caption" display="block" gutterBottom>
        {title}
      </Typography>
    </>
  );
};

ForwardOptionsComponent.propTypes = {
  title: PropTypes.string.isRequired,
  options: PropTypes.object.isRequired
};

export default ForwardOptionsComponent;
